@@ -2,7 +2,7 @@
 //
 // Copyright 2005 Dominick Samperi
 //
-// $Id: curves.cpp,v 1.2 2006/01/10 22:19:34 dsamperi Exp $
+// $Id: curves.cpp,v 1.7 2007/12/31 01:57:42 edd Exp $
 //
 // This program is part of the RQuantLib library for R (GNU S).
 // It is made available under the terms of the GNU General Public
@@ -75,29 +75,30 @@ boost::shared_ptr<RateHelper> ObservableDB::getRateHelper(string& ticker, Rate r
 	boost::shared_ptr<Quote> quote(new SimpleQuote(r));
 	boost::shared_ptr<RateHelper> depo(new DepositRateHelper(
 	    Handle<Quote>(quote),
-            n1, units, fixingDays,	
-            calendar, ModifiedFollowing, depositDayCounter));
+            n1*units, fixingDays,	
+            calendar, ModifiedFollowing, 
+	    true, fixingDays, depositDayCounter));
 	return depo;
     }
     else if(type == RQLSwap) {
 	Frequency swFixedLegFrequency = Annual;
 	BusinessDayConvention swFixedLegConvention = Unadjusted;
 	DayCounter swFixedLegDayCounter = Thirty360(Thirty360::European);
-	Frequency swFloatingLegFrequency = Semiannual;
+        boost::shared_ptr<IborIndex> swFloatingLegIndex(new Euribor6M);
 	boost::shared_ptr<Quote> quote(new SimpleQuote(r));
 	boost::shared_ptr<RateHelper> swap(new SwapRateHelper(
             Handle<Quote>(quote),
-            n1, units, fixingDays,
+            n1*Years, /*fixingDays,*/
             calendar, swFixedLegFrequency,
             swFixedLegConvention, swFixedLegDayCounter,
-            swFloatingLegFrequency, ModifiedFollowing));
+            swFloatingLegIndex));
 	return swap;
     }
     else if(type == RQLFuture) {
 	Integer futMonths = 3;
-	Date imm = Date::nextIMMdate(settlementDate);
+	Date imm = IMM::nextDate(settlementDate);
 	for(int i = 1; i < n1; i++)
-	    imm = Date::nextIMMdate(imm+1);
+	    imm = IMM::nextDate(imm+1);
 	boost::shared_ptr<Quote> quote(new SimpleQuote(r));
 	boost::shared_ptr<RateHelper> future(new FuturesRateHelper(
 	    Handle<Quote>(quote),
@@ -111,7 +112,7 @@ boost::shared_ptr<RateHelper> ObservableDB::getRateHelper(string& ticker, Rate r
 	boost::shared_ptr<RateHelper> FRA(new FraRateHelper(
             Handle<Quote>(quote),
             n1, n2, fixingDays, calendar, ModifiedFollowing,
-            depositDayCounter));
+            true, fixingDays, depositDayCounter));
 	return FRA;
     }
     else {
@@ -143,7 +144,7 @@ const std::vector<boost::shared_ptr<RateHelper> >& curveInput,
     else if(interpWhat.compare("discount") == 0 &&
             interpHow.compare("spline") == 0) {
 	boost::shared_ptr<YieldTermStructure> ts(new
-	       PiecewiseYieldCurve<Discount,Cubic>(settlementDate, 
+	       PiecewiseYieldCurve<Discount,CubicSpline>(settlementDate, 
 	       curveInput, dayCounter, tolerance));
 	return ts;
     }
@@ -164,7 +165,7 @@ const std::vector<boost::shared_ptr<RateHelper> >& curveInput,
     else if(interpWhat.compare("forward") == 0 &&
             interpHow.compare("spline") == 0) {
 	boost::shared_ptr<YieldTermStructure> ts(new
-	       PiecewiseYieldCurve<ForwardRate,Cubic>(settlementDate, 
+	       PiecewiseYieldCurve<ForwardRate,CubicSpline>(settlementDate, 
 	       curveInput, dayCounter, tolerance));
 	return ts;
     }
@@ -185,13 +186,13 @@ const std::vector<boost::shared_ptr<RateHelper> >& curveInput,
     else if(interpWhat.compare("zero") == 0 &&
             interpHow.compare("spline") == 0) {
 	boost::shared_ptr<YieldTermStructure> ts(new
-	       PiecewiseYieldCurve<ZeroYield,Cubic>(settlementDate, 
+	       PiecewiseYieldCurve<ZeroYield,CubicSpline>(settlementDate, 
 	       curveInput, dayCounter, tolerance));
 	return ts;
     }
     else {
-	Rprintf("interpWhat = %s\n", interpWhat.c_str());
-	Rprintf("interpHow  = %s\n", interpHow.c_str());
+      Rprintf((char*)"interpWhat = %s\n", interpWhat.c_str());
+      Rprintf((char*)"interpHow  = %s\n", interpHow.c_str());
 	throw range_error("What/How term structure options not recognized");
     }
 }
